@@ -2,7 +2,7 @@
 #'
 #' This function helps you quickly generate simulation data based on logistic model.
 #' You just need to input the sample and dimension of the data
-#' you want to generate and the covariance parameter pho.
+#' you want to generate and the covariance parameter rho.
 #'
 #' @param n Number of subjects in the dataset to be simulated. It will also equal to the
 #' number of rows in the dataset to be simulated, because it is assumed that each
@@ -24,26 +24,21 @@
 #' @importFrom MASS mvrnorm
 #' @importFrom stats rbinom
 #' @export
-#' @author Xuewei Cheng \email{xwcheng@csu.edu.cn}
+#' @author Xuewei Cheng \email{xwcheng@hunnu.edu.cn}
 #' @examples
-#' n=100;
-#' p=200;
-#' rho=0.5;
-#' data=GendataLGM(n,p,rho)
-GendataLGM <- function(n,p,rho,
-      beta=c(rep(1,5),rep(0,p-5)))# n sample size; p dimension size.
+#' n <- 100
+#' p <- 200
+#' rho <- 0.5
+#' data <- GendataLGM(n, p, rho)
+GendataLGM <- function(n, p, rho,
+                       beta = c(rep(1, 5), rep(0, p - 5))) # n sample size; p dimension size.
 {
-  sig=matrix(0,p,p);
-  sig=rho^abs(row(sig)-col(sig));
-  diag(sig)<-rep(1,p);
-  X=mvrnorm(n,rep(0,p),sig);
-  feta=X%*%beta;
-  fprob=exp(feta)/(1+exp(feta))
-  Y=rbinom(n,1,fprob)
-  return(list(X=X,Y=Y));
+  sig <- matrix(0, p, p)
+  sig <- rho^abs(row(sig) - col(sig))
+  diag(sig) <- rep(1, p)
+  X <- mvrnorm(n, rep(0, p), sig)
+  feta <- X %*% beta
+  fprob <- exp(feta) / (1 + exp(feta))
+  Y <- rbinom(n, 1, fprob)
+  return(list(X = X, Y = Y))
 }
-
-
-
-
-
