@@ -2,7 +2,7 @@
 #'
 #' This function helps you quickly generate simulation data based on linear model.
 #' You just need to input the sample and dimension of the data
-#' you want to generate and the covariance parameter pho.
+#' you want to generate and the covariance parameter rho.
 #'
 #' @param n Number of subjects in the dataset to be simulated. It will also equal to the
 #' number of rows in the dataset to be simulated, because it is assumed that each
@@ -27,33 +27,28 @@
 #' @importFrom stats rt
 #' @importFrom stats rcauchy
 #' @export
-#' @author Xuewei Cheng \email{xwcheng@csu.edu.cn}
+#' @author Xuewei Cheng \email{xwcheng@hunnu.edu.cn}
 #' @examples
-#' n=100;
-#' p=200;
-#' rho=0.5;
-#' data=GendataLM(n,p,rho,error="gaussian")
-GendataLM <- function(n,p,rho,
-        beta=c(rep(1,5),rep(0,p-5)),
-        error=c("gaussian","t","cauchy"))# n sample size; p dimension size.
+#' n <- 100
+#' p <- 200
+#' rho <- 0.5
+#' data <- GendataLM(n, p, rho, error = "gaussian")
+GendataLM <- function(n, p, rho,
+                      beta = c(rep(1, 5), rep(0, p - 5)),
+                      error = c("gaussian", "t", "cauchy")) # n sample size; p dimension size.
 {
-  sig=matrix(0,p,p);
-  sig=rho^abs(row(sig)-col(sig));
-  diag(sig)<-rep(1,p);
-  X=mvrnorm(n,rep(0,p),sig);
-  if (error=="gaussian" | is.null(error)){
-    Y=X%*%beta+rnorm(n)
-  }else if(error=="t"){
-    Y=X%*%beta+rt(n,2)
-  }else if(error=="cauchy"){
-    Y=X%*%beta+rcauchy(n)
-  }else{
+  sig <- matrix(0, p, p)
+  sig <- rho^abs(row(sig) - col(sig))
+  diag(sig) <- rep(1, p)
+  X <- mvrnorm(n, rep(0, p), sig)
+  if (error == "gaussian" | is.null(error)) {
+    Y <- X %*% beta + rnorm(n)
+  } else if (error == "t") {
+    Y <- X %*% beta + rt(n, 2)
+  } else if (error == "cauchy") {
+    Y <- X %*% beta + rcauchy(n)
+  } else {
     stop("The author has not implemented this error term yet.")
   }
-  return(list(X=X,Y=Y));
+  return(list(X = X, Y = Y))
 }
-
-
-
-
-
