@@ -2,7 +2,7 @@
 #'
 #' This function helps you quickly generate simulation data based on poisson model.
 #' You just need to input the sample and dimension of the data
-#' you want to generate and the covariance parameter pho.
+#' you want to generate and the covariance parameter rho.
 #' The simulated examples based on poisson model are significant popular
 #' in the screening procedures, such as Model 1.f in Liu et al.(2020).
 #'
@@ -26,29 +26,24 @@
 #' @importFrom MASS mvrnorm
 #' @importFrom stats rpois
 #' @export
-#' @author Xuewei Cheng \email{xwcheng@csu.edu.cn}
+#' @author Xuewei Cheng \email{xwcheng@hunnu.edu.cn}
 #' @examples
-#' n=100;
-#' p=200;
-#' rho=0.5;
-#' data=GendataPM(n,p,rho)
+#' n <- 100
+#' p <- 200
+#' rho <- 0.5
+#' data <- GendataPM(n, p, rho)
 #'
 #' @references
 #'
 #' Liu, W., Y. Ke, J. Liu, and R. Li (2020). Model-free feature screening and FDR control with knockoff features. Journal of the American Statistical Association, 1–16.
-GendataPM <- function(n,p,rho,
-        beta=c(rep(1,5),rep(0,p-5)))# n sample size; p dimension size.
+GendataPM <- function(n, p, rho,
+                      beta = c(rep(1, 5), rep(0, p - 5))) # n sample size; p dimension size.
 {
-  sig=matrix(0,p,p);
-  sig=rho^abs(row(sig)-col(sig));
-  diag(sig)<-rep(1,p);
-  X=mvrnorm(n,rep(0,p),sig);
-  myrates=exp(X%*%beta)
-  Y=rpois(n,myrates)
-  return(list(X=X,Y=Y));
+  sig <- matrix(0, p, p)
+  sig <- rho^abs(row(sig) - col(sig))
+  diag(sig) <- rep(1, p)
+  X <- mvrnorm(n, rep(0, p), sig)
+  myrates <- exp(X %*% beta)
+  Y <- rpois(n, myrates)
+  return(list(X = X, Y = Y))
 }
-
-
-
-
-
