@@ -2,7 +2,7 @@
 #'
 #' This function helps you quickly generate simulation data based on transformation model.
 #' You just need to input the sample and dimension of the data
-#' you want to generate and the covariance parameter pho.
+#' you want to generate and the covariance parameter rho.
 #' This simulated example comes from Example 3.a introduced by Zhu et al.(2011)
 #'
 #' @param n Number of subjects in the dataset to be simulated. It will also equal to the
@@ -28,38 +28,33 @@
 #' @importFrom stats rt
 #' @importFrom stats rcauchy
 #' @export
-#' @author Xuewei Cheng \email{xwcheng@csu.edu.cn}
+#' @author Xuewei Cheng \email{xwcheng@hunnu.edu.cn}
 #' @examples
-#' n=100;
-#' p=200;
-#' rho=0.5;
-#' data=GendataTM(n,p,rho,error="gaussian")
+#' n <- 100
+#' p <- 200
+#' rho <- 0.5
+#' data <- GendataTM(n, p, rho, error = "gaussian")
 #'
 #' @references
 #'
 #' Zhu, L.-P., L. Li, R. Li, and L.-X. Zhu (2011). Model-free feature screening for ultrahigh-dimensional data. Journal of the American Statistical Association 106(496), 1464–1475.
-GendataTM <- function(n,p,rho,
-        beta=c(rep(1,5),rep(0,p-5)),
-        error=c("gaussian","t","cauchy"))# n sample size; p dimension size.
+GendataTM <- function(n, p, rho,
+                      beta = c(rep(1, 5), rep(0, p - 5)),
+                      error = c("gaussian", "t", "cauchy")) # n sample size; p dimension size.
 {
-  sig=matrix(0,p,p);
-  sig=rho^abs(row(sig)-col(sig));
-  diag(sig)<-rep(1,p);
-  X=mvrnorm(n,rep(0,p),sig);
-  myrates=exp(X%*%beta)
-  if (error=="gaussian" | is.null(error)){
-    Y=myrates*exp(rnorm(n))
-  }else if(error=="t"){
-    Y=myrates*exp(rt(n,2))
-  }else if(error=="cauchy"){
-    Y=myrates*exp(rcauchy(n))
-  }else{
+  sig <- matrix(0, p, p)
+  sig <- rho^abs(row(sig) - col(sig))
+  diag(sig) <- rep(1, p)
+  X <- mvrnorm(n, rep(0, p), sig)
+  myrates <- exp(X %*% beta)
+  if (error == "gaussian" | is.null(error)) {
+    Y <- myrates * exp(rnorm(n))
+  } else if (error == "t") {
+    Y <- myrates * exp(rt(n, 2))
+  } else if (error == "cauchy") {
+    Y <- myrates * exp(rcauchy(n))
+  } else {
     stop("The author has not implemented this error term yet.")
   }
-  return(list(X=X,Y=Y));
+  return(list(X = X, Y = Y))
 }
-
-
-
-
-
